==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/ka_GE.js <==
OC.L10N.register(
    "lib",
    {
    "Help" : "დახმარება",
    "Personal" : "პირადი",
    "Users" : "მომხმარებელი",
    "Admin" : "ადმინისტრატორი",
    "today" : "დღეს",
    "yesterday" : "გუშინ",
    "last month" : "გასულ თვეში",
    "last year" : "ბოლო წელს",
    "seconds ago" : "წამის წინ",
    "web services under your control" : "web services under your control",
    "Application is not enabled" : "აპლიკაცია არ არის აქტიური",
    "Authentication error" : "ავთენტიფიკაციის შეცდომა",
    "Token expired. Please reload page." : "Token–ს ვადა გაუვიდა. გთხოვთ განაახლოთ გვერდი.",
    "%s enter the database username." : "%s შეიყვანეთ ბაზის იუზერნეიმი.",
    "%s enter the database name." : "%s შეიყვანეთ ბაზის სახელი.",
    "%s you may not use dots in the database name" : "%s არ მიუთითოთ წერტილი ბაზის სახელში",
    "Oracle username and/or password not valid" : "Oracle იუზერნეიმი და/ან პაროლი არ არის სწორი",
    "DB Error: \"%s\"" : "DB შეცდომა: \"%s\"",
    "Offending command was: \"%s\"" : "Offending ბრძანება იყო: \"%s\"",
    "You need to enter either an existing account or the administrator." : "თქვენ უნდა შეიყვანოთ არსებული მომხმარებელის სახელი ან ადმინისტრატორი.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Offending ბრძანება იყო: \"%s\", სახელი: %s, პაროლი: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL იუზერნეიმი და/ან პაროლი არ არის სწორი",
    "Set an admin username." : "დააყენეთ ადმინისტრატორის სახელი.",
    "Set an admin password." : "დააყენეთ ადმინისტრატორის პაროლი.",
    "Could not find category \"%s\"" : "\"%s\" კატეგორიის მოძებნა ვერ მოხერხდა",
    "Apps" : "აპლიკაციები",
    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
    "A valid password must be provided" : "უნდა მიუთითოთ არსებული პაროლი"
},
"nplurals=1; plural=0;");

==> owncloud-9.1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/ka_GE.js <==
OC.L10N.register(
    "lib",
    {
    "today" : "დღეს",
    "yesterday" : "გუშინ",
    "last month" : "გასულ თვეში",
    "last year" : "ბოლო წელს",
    "seconds ago" : "წამის წინ",
    "%s enter the database username." : "%s შეიყვანეთ ბაზის იუზერნეიმი.",
    "%s enter the database name." : "%s შეიყვანეთ ბაზის სახელი.",
    "%s you may not use dots in the database name" : "%s არ მიუთითოთ წერტილი ბაზის სახელში",
    "Oracle username and/or password not valid" : "Oracle იუზერნეიმი და/ან პაროლი არ არის სწორი",
    "DB Error: \"%s\"" : "DB შეცდომა: \"%s\"",
    "Offending command was: \"%s\"" : "Offending ბრძანება იყო: \"%s\"",
    "You need to enter either an existing account or the administrator." : "თქვენ უნდა შეიყვანოთ არსებული მომხმარებელის სახელი ან ადმინისტრატორი.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Offending ბრძანება იყო: \"%s\", სახელი: %s, პაროლი: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL იუზერნეიმი და/ან პაროლი არ არის სწორი",
    "Set an admin username." : "დააყენეთ ადმინისტრატორის სახელი.",
    "Set an admin password." : "დააყენეთ ადმინისტრატორის პაროლი.",
    "Could not find category \"%s\"" : "\"%s\" კატეგორიის მოძებნა ვერ მოხერხდა",
    "Apps" : "აპლიკაციები",
    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
    "A valid password must be provided" : "უნდა მიუთითოთ არსებული პაროლი",
    "Help" : "დახმარება",
    "Personal" : "პირადი",
    "Users" : "მომხმარებელი",
    "Admin" : "ადმინისტრატორი",
    "web services under your control" : "web services under your control",
    "Application is not enabled" : "აპლიკაცია არ არის აქტიური",
    "Authentication error" : "ავთენტიფიკაციის შეცდომა",
    "Token expired. Please reload page." : "Token–ს ვადა გაუვიდა. გთხოვთ განაახლოთ გვერდი."
},
"nplurals=1; plural=0;");
